@@ -25,6 +25,14 @@ class InitCommandTest extends TestCase
         $this->assertEquals('john@example.com', $author['email']);
     }
 
+    public function testParseValidAuthorStringWithoutEmail()
+    {
+        $command = new InitCommand;
+        $author = $command->parseAuthorString('John Smith');
+        $this->assertEquals('John Smith', $author['name']);
+        $this->assertNull($author['email']);
+    }
+
     public function testParseValidUtf8AuthorString()
     {
         $command = new InitCommand;
