@@ -12,6 +12,7 @@
 
 namespace Composer\Test\Util;
 
+use Composer\Downloader\TransportException;
 use Composer\IO\IOInterface;
 use Composer\Test\TestCase;
 use Composer\Util\AuthHelper;
@@ -473,6 +474,9 @@ class AuthHelperTest extends TestCase
         $this->authHelper->storeAuth($origin, $storeAuth);
     }
 
+    /**
+     * @return void
+     */
     public function testStoreAuthWithPromptInvalidAnswer()
     {
         $this->setExpectedException('RuntimeException');
@@ -513,6 +517,44 @@ class AuthHelperTest extends TestCase
         $this->authHelper->storeAuth($origin, $storeAuth);
     }
 
+    /**
+     * @return void
+     */
+    public function testPromptAuthIfNeededGitLabNoAuthChange()
+    {
+        $this->setExpectedException('Composer\Downloader\TransportException');
+
+        $origin = 'gitlab.com';
+
+        $this->io
+            ->method('hasAuthentication')
+            ->with($origin)
+            ->willReturn(true);
+
+        $this->io
+            ->method('getAuthentication')
+            ->with($origin)
+            ->willReturn(array(
+                'username' => 'gitlab-user',
+                'password' => 'gitlab-password',
+            ));
+
+        $this->io
+            ->expects($this->once())
+            ->method('setAuthentication')
+            ->with('gitlab.com', 'gitlab-user', 'gitlab-password');
+
+        $this->config
+            ->method('get')
+            ->willReturnMap(array(
+                array('github-domains', 0, array()),
+                array('gitlab-domains', 0, array('gitlab.com')),
+                array('gitlab-token', 0, array('gitlab.com' => array('username' => 'gitlab-user', 'token' => 'gitlab-password'))),
+            ));
+
+        $this->authHelper->promptAuthIfNeeded('https://gitlab.com/acme/archive.zip', $origin, 404, 'GitLab requires authentication and it was not provided');
+    }
+
     /**
      * @param string                     $origin
      * @param array<string, string|null> $auth
